@@ -153,9 +153,9 @@ class CERNGroup(Group):
                     'primaryAccountEmail',
                     'personId',
                 ],
-                'recursive': 'true'
             }
-            results = self.provider._fetch_all(api_session, f'/api/v1.0/Group/{gid}/memberidentities', params)[0]
+            results = self.provider._fetch_all(api_session, f'/api/v1.0/Group/{gid}/memberidentities/precomputed',
+                                               params)[0]
         for res in results:
             del res['id']  # id is always included
             self.provider._fix_phone(res)
@@ -383,7 +383,7 @@ class CERNIdentityProvider(IdentityProvider):
         with self._get_api_session() as api_session:
             identifier = identifier.replace('/', '%2F')  # edugain identifiers sometimes contain slashes
             resp = api_session.get(f'{self.authz_api_base}/api/v1.0/IdentityMembership/{identifier}/precomputed')
-            if resp.status_code == 404 or resp.status_code == 500:
+            if resp.status_code == 404:
                 return set()
             resp.raise_for_status()
             results = resp.json()['data']
